OC.L10N.register(
    "comments",
    {
    "<strong>Comments</strong> for files" : "<strong>Comments</strong> for files",
    "%1$s commented" : "%1$s commented",
    "%1$s commented on %2$s" : "%1$s commented on %2$s",
    "Comments" : "Comments",
    "Type in a new comment..." : "Type in a new comment...",
    "Delete comment" : "Delete comment",
    "Post" : "Post",
    "Cancel" : "Cancel",
    "Edit comment" : "Edit comment",
    "[Deleted user]" : "[Deleted user]",
    "No other comments available" : "No other comments available",
    "More comments..." : "More comments...",
    "Save" : "Save",
    "Allowed characters {count} of {max}" : "Allowed characters {count} of {max}",
    "{count} unread comments" : "{count} unread comments",
    "Comment" : "Comment",
    "<strong>Comments</strong> for files" : "<strong>Comments</strong> for files"
},
"nplurals=2; plural=(n != 1);");
